Bildad.Job.JobRuns (Bildad v0.1.11)

Copy Markdown View Source

Manages job runs.

Summary

Functions

Returns the number of job runs. (This is useful for pagination.)

Lists all the job runs with pagination.

Lists all the jobs that were running, have not been killed and have expired without pagination.

Lists all the jobs that were running, have not been killed and have expired with pagination (with the default page size if nil provided as the page size).

Lists all the job runs for the provided job run identifier without pagination.

Lists all the jobs that have finished with the provided result without pagination.

Lists all the jobs that have finished with the provided result with pagination (with the default page size if nil provided as the page size).

Lists all the jobs that are running and have timed out without pagination.

Lists all the jobs that are running and have timed out with pagination (with the default page size if nil provided as the page size).

Lists all job runs that are currently in RUNNING status.

Functions

get_number_of_job_runs(job_config)

Returns the number of job runs. (This is useful for pagination.)

list_all_job_runs(job_config, page, limit)

Lists all the job runs with pagination.

list_expired_jobs(job_config)

Lists all the jobs that were running, have not been killed and have expired without pagination.

list_expired_jobs(job_config, page, limit)

Lists all the jobs that were running, have not been killed and have expired with pagination (with the default page size if nil provided as the page size).

list_job_runs_for_identifier(job_config, job_run_identifier)

Lists all the job runs for the provided job run identifier without pagination.

list_job_runs_for_result(job_config, result)

Lists all the jobs that have finished with the provided result without pagination.

list_job_runs_for_result(job_config, result, page, limit)

Lists all the jobs that have finished with the provided result with pagination (with the default page size if nil provided as the page size).

list_job_runs_to_kill(job_config)

Lists all the jobs that are running and have timed out without pagination.

list_job_runs_to_kill(job_config, page, limit)

Lists all the jobs that are running and have timed out with pagination (with the default page size if nil provided as the page size).

list_running_job_runs(job_config)

Lists all job runs that are currently in RUNNING status.

preload_job_runs(job_runs, job_config)