Bildad.Job.JobTemplates (Bildad v0.1.11)

Copy Markdown View Source

Manages job templates.

Summary

Functions

Creates a new job template with the provided attributes.

Deletes the provided job template.

Lists all the active job templates without pagination.

Lists all the active job templates with pagination (with the default page size if nil provided as the page size).

Lists all the active job templates without pagination.

Lists all the active job templates with pagination (with the default page size if nil provided as the page size).

Lists all the inactive job templates without pagination.

Lists all the inactive job templates with pagination (with the default page size if nil provided as the page size).

Lists all the active job templates without pagination.

Lists all the active job templates with pagination (with the default page size if nil provided as the page size).

Updates the provided job template with the provided attributes.

Functions

create_job_template(job_config, attrs)

Creates a new job template with the provided attributes.

Note that the module_name should be a string version of the Elixir module name that will be used to run the job.

Note that the job_context_schema should be a map that represents the schema of the context that will be passed to the job module. It will be used to validate the context before running the job.

delete_job_template(job_config, job_template)

Deletes the provided job template.

list_active_job_templates(job_config)

Lists all the active job templates without pagination.

list_active_job_templates(job_config, page, limit)

Lists all the active job templates with pagination (with the default page size if nil provided as the page size).

list_all_job_templates(job_config)

Lists all the active job templates without pagination.

list_all_job_templates(job_config, page, limit)

Lists all the active job templates with pagination (with the default page size if nil provided as the page size).

list_inactive_job_templates(job_config)

Lists all the inactive job templates without pagination.

list_inactive_job_templates(job_config, page, limit)

Lists all the inactive job templates with pagination (with the default page size if nil provided as the page size).

list_job_templates(job_config)

Lists all the active job templates without pagination.

list_job_templates(job_config, page, limit)

Lists all the active job templates with pagination (with the default page size if nil provided as the page size).

update_job_template(job_config, job_template, attrs)

Updates the provided job template with the provided attributes.